/*******************************************************************
 * libfaxophone                                                    *
 * Created by Jan-Michael Brummer                                  *
 * All parts are distributed under the terms of GPLv2. See COPYING *
 *******************************************************************/

/**
 * \file debug.c
 * \brief Debug message function
 */

#include <stdio.h>
#include <stdarg.h>
#include <time.h>

/**
 * \brief Internal debug message function
 * \param nLevel requested message debug level
 * \param pnName function name
 * \param pnFormat string format + parameters
 */
void FopDebugIntern( unsigned char nLevel, const char *pnName, char *pnFormat, ... ) {
	time_t sTime = time( NULL );
	struct tm *psNow = localtime( &sTime );
	va_list args;

	/* Prepend time and function name */
	fprintf( stdout, "%02d:%02d:%02d %s(): ", psNow -> tm_hour, psNow -> tm_min, psNow -> tm_sec, pnName );
	va_start( args, pnFormat );
	/* Now print message */
	vfprintf( stdout, pnFormat, args );
	va_end( args );

	/* flush output */
	fflush( stdout );
}
